from setuptools import setup

setup(
    name='identitylib',
    version='1.0.1',
    description='identity function',
    install_requires=[],
    packages=['identity'],
    author_email='avtahovfarit@gmail.com',
)